@@ -247,7 +247,7 @@ namespace giac {
 
   gen _print(const gen & args,GIAC_CONTEXT);  
   extern const unary_function_ptr * const  at_print;
-#if !defined RTOS_THREADX && !defined NSPIRE
+#if !defined RTOS_THREADX && !defined NSPIRE && !defined FXCG
   extern const unary_function_eval __print;
 #endif
 
@@ -317,6 +317,13 @@ namespace giac {
   extern const unary_function_ptr * const  at_divcrement;
   extern const unary_function_ptr * const  at_iquosto;
   extern const unary_function_ptr * const  at_iremsto;
+  extern const unary_function_ptr * const  at_andsto;
+  extern const unary_function_ptr * const  at_orsto;
+  extern const unary_function_ptr * const  at_xorsto;
+  extern const unary_function_ptr * const  at_shiftsto;
+  gen _shiftsto(const gen & a,const context * contextptr);
+  extern const unary_function_ptr * const  at_rotatesto;
+  gen _rotatesto(const gen & a,const context * contextptr);
   gen sto(const gen & a,const gen & b,GIAC_CONTEXT);
   gen sto(const gen & a,const gen & b,bool in_place,GIAC_CONTEXT);  
   gen _sto(const gen & g,const context * contextptr);
@@ -428,7 +435,7 @@ namespace giac {
   symbolic symb_pow(const gen & a,const gen & b);
   std::string cprintaspow(const gen & feuille,const char * sommetstr_orig,GIAC_CONTEXT);
 #ifndef GIAC_HAS_STO_38
-#ifdef NSPIRE
+#if defined NSPIRE || defined FXCG
   extern const alias_unary_function_eval __pow;
 #else
   extern unary_function_eval __pow;
